exec

package
v0.0.0-...-d5e5f51 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package exec is a generated GoMock package.

Package exec is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockCmd

type MockCmd struct {
	// contains filtered or unexported fields
}

MockCmd is a mock of Cmd interface.

func NewMockCmd

func NewMockCmd(ctrl *gomock.Controller) *MockCmd

NewMockCmd creates a new mock instance.

func (*MockCmd) EXPECT

func (m *MockCmd) EXPECT() *MockCmdMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockCmd) Output

func (m *MockCmd) Output() ([]byte, error)

Output mocks base method.

type MockCmdMockRecorder

type MockCmdMockRecorder struct {
	// contains filtered or unexported fields
}

MockCmdMockRecorder is the mock recorder for MockCmd.

func (*MockCmdMockRecorder) Output

func (mr *MockCmdMockRecorder) Output() *gomock.Call

Output indicates an expected call of Output.

type MockExec

type MockExec struct {
	// contains filtered or unexported fields
}

MockExec is a mock of Exec interface.

func NewMockExec

func NewMockExec(ctrl *gomock.Controller) *MockExec

NewMockExec creates a new mock instance.

func (*MockExec) Command

func (m *MockExec) Command(name string, arg ...string) exec.Cmd

Command mocks base method.

func (*MockExec) EXPECT

func (m *MockExec) EXPECT() *MockExecMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

type MockExecMockRecorder

type MockExecMockRecorder struct {
	// contains filtered or unexported fields
}

MockExecMockRecorder is the mock recorder for MockExec.

func (*MockExecMockRecorder) Command

func (mr *MockExecMockRecorder) Command(name any, arg ...any) *gomock.Call

Command indicates an expected call of Command.

Jump to