debug

package
v0.0.0-...-d5e5f51 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type FileDumper

type FileDumper struct {
	// contains filtered or unexported fields
}

FileDumper handles file-based debugging output

func NewFileDumper

func NewFileDumper(config appconfig.DumpConfig) *FileDumper

NewFileDumper creates a new file dumper with the given configuration

func (*FileDumper) CleanupOldFiles

func (fd *FileDumper) CleanupOldFiles() error

CleanupOldFiles removes debug files older than the retention period

func (*FileDumper) DumpToFile

func (fd *FileDumper) DumpToFile(data any, prefix, suffix string) (string, error)

DumpToFile writes any JSON-serializable data to a file and returns the filename

Jump to