Documentation
¶
Overview ¶
Package exec is a generated GoMock package.
Package exec is a generated GoMock package.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockCmd ¶
type MockCmd struct {
// contains filtered or unexported fields
}
MockCmd is a mock of Cmd interface.
func NewMockCmd ¶
func NewMockCmd(ctrl *gomock.Controller) *MockCmd
NewMockCmd creates a new mock instance.
func (*MockCmd) EXPECT ¶
func (m *MockCmd) EXPECT() *MockCmdMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockCmdMockRecorder ¶
type MockCmdMockRecorder struct {
// contains filtered or unexported fields
}
MockCmdMockRecorder is the mock recorder for MockCmd.
func (*MockCmdMockRecorder) Output ¶
func (mr *MockCmdMockRecorder) Output() *gomock.Call
Output indicates an expected call of Output.
type MockExec ¶
type MockExec struct {
// contains filtered or unexported fields
}
MockExec is a mock of Exec interface.
func NewMockExec ¶
func NewMockExec(ctrl *gomock.Controller) *MockExec
NewMockExec creates a new mock instance.
func (*MockExec) EXPECT ¶
func (m *MockExec) EXPECT() *MockExecMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockExecMockRecorder ¶
type MockExecMockRecorder struct {
// contains filtered or unexported fields
}
MockExecMockRecorder is the mock recorder for MockExec.
Click to show internal directories.
Click to hide internal directories.